from .client import Client

import jwt
import requests

class Machine(object):
    def __init__(self, url, headers={}):
        self.msg = None
        self.url = url
        self.headers = headers

    def check_existence(self, cloudspace_id, machine_name):
        """
        Checks if machine name exists
        returns the machine ID if machine exists
        """
        body_data = {}
        body_data['cloudspaceId'] = cloudspace_id
        response = requests.post(self.url + '/cloudapi/machines/list', json=body_data, headers=self.headers)
        machines = response.json()
        for machine in machines:
            if machine['name'] == machine_name:
                return machine['id']
        return None
    
    def create(self, cloudspace_id, machine_name, description, 
            size_id, image_id, disk_size, data_disks, vcpus, memory):
        """
        Makes new machine based on input values
        """
        body_data = {}
        body_data['cloudspaceId'] = cloudspace_id
        body_data['name'] = machine_name
        body_data['description'] = description
        body_data['imageId'] = image_id
        if size_id is not None:
            body_data['sizeId'] = size_id
        else:
            body_data['vcpus'] = vcpus
            body_data['memory'] = memory
        body_data['disksize'] = disk_size
        body_data['datadisks'] = data_disks
        response = requests.post(self.url + '/cloudapi/machines/create', json=body_data, headers=self.headers)
        return Client.check_response(response)

    def get(self, machine_id):
        """
        Returns the machine information
        """
        body_data = {}
        body_data['machineId'] = machine_id
        response = requests.post(self.url + '/cloudapi/machines/get', json=body_data, headers=self.headers)
        return Client.check_response(response).json()
    
    def delete(self, machine_id):
        """
        Removes selected machine
        """
        body_data = {}
        body_data['machineId'] = machine_id
        body_data['permanently'] = True
        response = requests.post(self.url + '/cloudapi/machines/delete', json=body_data, headers=self.headers)
        return Client.check_response(response)

    def update(self, machine_id, machine_name, description, size_id, vcpus, memory):
        """
        Updates the machine
        """
        body_data = {}
        body_data['machineId'] = machine_id
        body_data['name'] = machine_name
        body_data['description'] = description
        self.update_size(machine_id, size_id, vcpus=vcpus, memory=memory)
        response = requests.post(self.url + '/cloudapi/machines/update', json=body_data, headers=self.headers)
        return Client.check_response(response)

    def update_size(self, machine_id, size_id, vcpus, memory):
        """
        Update the machine's size
        """
        body_data = {}
        if size_id is not None:
            body_data['sizeId'] = size_id
        else:
            body_data['vcpus'] = vcpus
            body_data['memory'] = memory
        body_data['machineId'] = machine_id
        response = requests.post(self.url + '/cloudapi/machines/resize', json=body_data, headers=self.headers)
        return Client.check_response(response)




from .client import Client

import jwt
import requests

class Disk(object):
    def __init__(self, url, headers={}):
        self.url = url
        self.headers = headers
        self.msg = None
    
    def check_existence(self, machine_details, disk_name):
        """
        Returns disk information
        """
        disks = machine_details['disks']
        for disk in disks:
            if disk['name'] == disk_name:
                return disk['id']
        return None

    def add(self, machine_id, disk_name, disk_description, disk_size,
            disk_type, ssd_size, disk_iops):
        """
        Updates size ID
        """
        body_data = {}
        body_data['machineId'] = machine_id
        body_data['diskName'] = disk_name
        body_data['description'] = disk_description
        body_data['size'] = disk_size
        body_data['type'] = disk_type
        body_data['ssdSize'] = ssd_size
        body_data['iops'] = disk_iops
        response = requests.post(self.url + '/cloudapi/machines/addDisk', json=body_data, headers=self.headers)
        return Client.check_response(response)
    
    def delete(self, disk_id):
        """
        Deletes disk
        """
        body_data = {}
        body_data['diskId'] = disk_id
        body_data['detach'] = True
        body_data['permanently'] = True
        response = requests.post(self.url + '/cloudapi/disks/delete', json=body_data, headers=self.headers)
        return Client.check_response(response)

    def get(self, disk_id):
        """
        Get all the information regarding the added or deleted disk
        """
        body_data = {}
        body_data['diskId'] = disk_id
        response = requests.post(self.url + '/cloudapi/disks/get', json=body_data, headers=self.headers)
        return Client.check_response(response).json()



from .client import Client

import jwt
import requests

class Portforwarding(object):
    def __init__(self, url, headers={}):
        self.url = url
        self.headers = headers
        self.msg = None
    
    def create(self, machine_id, public_ip, cloudspace_id, public_port, local_port, protocol):
        """
        Creates new port forwarding
        """
        body_data = {}
        body_data['cloudspaceId'] = cloudspace_id
        body_data['machineId'] = machine_id
        body_data['publicIp'] = public_ip
        body_data['publicPort'] = public_port
        body_data['localPort'] = local_port
        body_data['protocol'] = protocol
        response = requests.post(self.url + '/cloudapi/portforwarding/create', json=body_data, headers=self.headers)
        return Client.check_response(response)
    
    def check_existence(self, machine_id, cloudspace_id, local_port, public_port):
        """
        Checks if port forwarding exists
        """
        ports = self.list(machine_id=machine_id, cloudspace_id=cloudspace_id)
        for port in ports:
            if port['localPort'] == str(local_port) and port['publicPort'] == str(public_port):
                return True
        return False
    
    def delete(self, machine_id, public_ip, cloudspace_id, public_port, local_port, protocol):
        """
        Deletes a port forwarding
        """
        body_data = {}
        body_data['cloudspaceId'] = cloudspace_id
        body_data['machineId'] = machine_id
        body_data['publicIp'] = public_ip
        body_data['publicPort'] = public_port
        body_data['localPort'] = local_port
        body_data['protocol'] = protocol
        response = requests.post(self.url + '/cloudapi/portforwarding/deleteByPort', json=body_data, headers=self.headers)
        return Client.check_response(response)
    
    def list(self, machine_id, cloudspace_id):
        """
        Gets all relevant information of port forward
        """
        body_data = {}
        body_data['cloudspaceId'] = cloudspace_id
        body_data['machineId'] = machine_id
        response = requests.post(self.url + '/cloudapi/portforwarding/list', json=body_data, headers=self.headers)
        return Client.check_response(response).json()


import requests

class Client(object):

    @staticmethod
    def check_response(response):
        """
        Checks the API response
        """
        if response.status_code in range(200, 299):
            return response
        else:
            raise DoError(response.text)

    @staticmethod
    def first_login(client_id, client_secret):
        """
        First login to get token
        """
        auth_data = {}
        auth_data['grant_type']= 'client_credentials'
        auth_data['client_id'] = str(client_id)
        auth_data['client_secret'] = str(client_secret)
        auth_data['response_type'] = 'id_token'

        response = requests.post('https://itsyou.online/v1/oauth/access_token', data=auth_data, headers={'Content-Type': 'application/x-www-form-urlencoded'})
        return response.text

class DoError(RuntimeError):
    pass


from .client import Client

import jwt
import requests

class Cloudspace(object):
    
    def __init__(self, url, headers={}):
        self.msg = None
        self.url = url
        self.headers = headers

    def check_existence(self, cloudspace_name):
        """
        Checks if cloudspace name exists
        returns the cloudspace ID if cloudspace exists
        """
        body_data = {}
        body_data['includedeleted'] = False
        response = requests.post(self.url + '/cloudapi/cloudspaces/list', json=body_data, headers=self.headers)
        cloudspaces = response.json()
        for cloudspace in cloudspaces:
            if cloudspace['name'] == cloudspace_name:
                cloudspace_id = cloudspace['id']
                return cloudspace_id
        return None

    def create(self, access, account_id, cloudspace_name, max_memory_capacity, 
            max_vdisk_capacity, max_cpu_capacity, max_network_peer_transfer, 
            max_num_public_ip):
        """
        Makes new cloudspace based on input values
        """
        body_data = {}
        body_data['accountId'] = account_id
        body_data['name'] = cloudspace_name
        body_data['location'] = self.get_location()
        body_data['access'] = access
        body_data['maxMemoryCapacity'] = max_memory_capacity
        body_data['maxVDiskCapacity'] = max_vdisk_capacity
        body_data['maxCPUCapacity'] = max_cpu_capacity
        body_data['maxNetworkPeerTransfer'] = max_network_peer_transfer
        body_data['maxNumPublicIP'] = max_num_public_ip
        response = requests.post(self.url + '/cloudapi/cloudspaces/create', json=body_data, headers=self.headers)
        return Client.check_response(response)

    def get(self, cloudspace_id):
        """
        Returns the cloudspace information
        """
        body_data = {}
        body_data['cloudspaceId'] = cloudspace_id
        response = requests.post(self.url + '/cloudapi/cloudspaces/get', json=body_data, headers=self.headers)
        return Client.check_response(response).json()

    def delete(self, cloudspace_id):
        """
        Deletes selected cloudspace
        """
        body_data = {}
        body_data['cloudspaceId'] = cloudspace_id
        body_data['permanently'] = True
        response = requests.post(self.url + '/cloudapi/cloudspaces/delete', json=body_data, headers=self.headers)
        return Client.check_response(response)

    def update(self, cloudspace_id, cloudspace_name, max_memory_capacity, max_cpu_capacity, max_network_peer_transfer, max_num_public_ip, 
            max_vdisk_capacity):
        """
        Updates selected cloudspace
        """
        body_data = {}
        body_data['cloudspaceId'] = cloudspace_id
        body_data['name'] = cloudspace_name
        body_data['maxMemoryCapacity'] = max_memory_capacity
        body_data['maxVDiskCapacity'] = max_vdisk_capacity
        body_data['maxCPUCapacity'] = max_cpu_capacity
        body_data['maxNetworkPeerTransfer'] = max_network_peer_transfer
        body_data['maxNumPublicIP'] = max_num_public_ip
        response = requests.post(self.url + '/cloudapi/cloudspaces/update', json=body_data, headers=self.headers)
        return Client.check_response(response)


    def get_location(self):
        res = self.url.split('://')
        return res[1].split('.', 1)[0]


from setuptools import setup
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='ovc',
      version='0.1.3',
      description='SDK for ansible modules used by GiG for their OpenVCloud platform',
      long_description=long_description,
      long_description_content_type="text/markdown",
      author='Stef Graces',
      license='Nubera BVBA',
      packages=setuptools.find_packages(),
       classifiers=[
        "Operating System :: OS Independent",
    ],)